@@ -4,8 +4,11 @@ OC.L10N.register(
     "Auto detect failed. Please use manual mode." : "فشل في عملية التحقق الآلي. الرجاء استخدام نمط الدليل.",
     "Updating account failed: " : "فشلت عملية تحديث الحساب :",
     "Creating account failed: " : "فشل في إنشاء الحساب:",
+    "Important mail" : "البريد الهام",
+    "Unread mail" : "البريد غير المقروء",
     "Mails" : "الرسائل",
     "Mail" : "البريد",
+    "Auto" : "تلقائي",
     "Name" : "الإسم",
     "Mail Address" : "عنوان البريد الإلكتروني",
     "Password" : "كلمة المرور",
@@ -25,6 +28,7 @@ OC.L10N.register(
     "SMTP Password" : "كلمة مرور SMTP",
     "Save" : "حفظ",
     "Connect" : "اتصال",
+    "Change name" : "تغيير الإسم",
     "Signature" : "التوقيع",
     "Mail server" : "خادم البريد",
     "Add mail account" : "أضف حساب بريدي",
@@ -41,6 +45,7 @@ OC.L10N.register(
     "No sent mailbox configured. Please pick one in the account settings." : "لم يتم اعداد الرسائل في المرسلة في صندوق البريد. يرجى اختيار واحد في اعدادات الحساب.",
     "Choose a file to add as attachment" : "اختر ملف لإضافته كمرفق",
     "Choose a file to share as a link" : "اختر ملفا لمشاركته كرابط",
+    "No messages" : "لاتوجد رسائل",
     "Draft: " : "المسودة:",
     "No trash mailbox configured" : "لم يتم اعداد سلة المحذوفات لصندوق البريد",
     "Could not delete message" : "لا يمكن حذف الرسالة",
@@ -60,7 +65,6 @@ OC.L10N.register(
     "Choose a folder to store the attachment in" : "اختر مجلد لتخزين المرفقات ",
     "Save all to Files" : "حفظ الجميع لـ الملفات",
     "The images have been blocked to protect your privacy." : "تم حجب هذه الصورة لحماية خصوصيتك",
-    "Show images from this sender" : "أظهر الصور من هذا المُرسل",
     "New message" : "رسالة جديدة",
     "Settings" : "الإعدادات",
     "Quota" : "الحصة",
@@ -69,6 +73,7 @@ OC.L10N.register(
     "Cancel" : "إلغاء",
     "Mark all as read" : "تحديد الكل كمقروء",
     "Clear cache" : "مسح ذاكرة التخزين المؤقتة",
+    "Delete mailbox" : "حذف صندوق البريد",
     "Not found" : "غير موجود",
     "Attachments were not copied. Please add them manually." : "المرفقات لم يتم نسخها. يرجى اضافتها يدويا.",
     "Reply" : "رد",
